@@ -4,7 +4,7 @@ import json
 
 import os
 this_dir, this_filename = os.path.split(__file__)
-DATA_PATH = os.path.join(this_dir,"data","id.csv")
+DATA_PATH = os.path.join(this_dir,"static","id.csv")
 csv = pd.read_csv(DATA_PATH)
 
 # csv = pd.read_csv('id.csv')
